

package com.zerog.ia.customcode.util.miscutils;

import com.zerog.ia.api.pub.*;

/**
 *	This is a simple CustomCodeAction that aborts the installation.
 *
 *	At uninstall-time, it does nothing.
 *
 *	@version 3.0.0
 */
public class AbortInstallAction extends CustomCodeAction
{
	/**
	 *	This is the method that is called at install-time.  The InstallerProxy
	 *	instance provides methods to access information in the installer,
	 *	set status, and control flow.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodeAction#install
	 */
	public void install( InstallerProxy ip ) throws InstallException
	{
		ip.abortInstallation( -1 );
	}

	/**
	 *	This is the method that is called at uninstall-time.  The DataInput
	 *	instance provides access to any information written at install-time
	 *	with the instance of DataOutput provided by UninstallerProxy.getLogOutput().
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodeAction#uninstall
	 */
	public void uninstall( UninstallerProxy up ) throws InstallException
	{

	}

	/**
	 *	This method will be called to display a status message during the
	 *	installation.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodeAction#getInstallStatusMessage
	 */
	public String getInstallStatusMessage()
	{
		return "";
	}

	/**
	 *	This method will be called to display a status message during the
	 *	uninstall.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodeAction#getUninstallStatusMessage
	 */
	public String getUninstallStatusMessage()
	{
		return "";
	}
}
